@@ -1,3 +1,4 @@
+import os
 import copy
 import collections
 import uuid
@@ -22,6 +23,8 @@ def new_folder_entity(
     name,
     folder_type,
     parent_id=None,
+    status=None,
+    tags=None,
     attribs=None,
     data=None,
     thumbnail_id=None,
@@ -32,19 +35,21 @@ def new_folder_entity(
     Args:
         name (str): Is considered as unique identifier of folder in project.
         folder_type (str): Type of folder.
-        parent_id (Optional[str]]): Id of parent folder.
+        parent_id (Optional[str]): Parent folder id.
+        status (Optional[str]): Product status.
+        tags (Optional[List[str]]): List of tags.
         attribs (Optional[Dict[str, Any]]): Explicitly set attributes
             of folder.
         data (Optional[Dict[str, Any]]): Custom folder data. Empty dictionary
             is used if not passed.
-        thumbnail_id (Optional[str]): Id of thumbnail related to folder.
+        thumbnail_id (Optional[str]): Thumbnail id related to folder.
         entity_id (Optional[str]): Predefined id of entity. New id is
             created if not passed.
 
     Returns:
         Dict[str, Any]: Skeleton of folder entity.
-    """
 
+    """
     if attribs is None:
         attribs = {}
 
@@ -54,7 +59,7 @@ def new_folder_entity(
     if parent_id is not None:
         parent_id = _create_or_convert_to_id(parent_id)
 
-    return {
+    output = {
         "id": _create_or_convert_to_id(entity_id),
         "name": name,
         # This will be ignored
@@ -64,6 +69,11 @@ def new_folder_entity(
         "attrib": attribs,
         "thumbnailId": thumbnail_id
     }
+    if status:
+        output["status"] = status
+    if tags:
+        output["tags"] = tags
+    return output
 
 
 def new_product_entity(
@@ -71,6 +81,7 @@ def new_product_entity(
     product_type,
     folder_id,
     status=None,
+    tags=None,
     attribs=None,
     data=None,
     entity_id=None
@@ -81,8 +92,9 @@ def new_product_entity(
         name (str): Is considered as unique identifier of
             product under folder.
         product_type (str): Product type.
-        folder_id (str): Id of parent folder.
+        folder_id (str): Parent folder id.
         status (Optional[str]): Product status.
+        tags (Optional[List[str]]): List of tags.
         attribs (Optional[Dict[str, Any]]): Explicitly set attributes
             of product.
         data (Optional[Dict[str, Any]]): product entity data. Empty dictionary
@@ -92,8 +104,8 @@ def new_product_entity(
 
     Returns:
         Dict[str, Any]: Skeleton of product entity.
-    """
 
+    """
     if attribs is None:
         attribs = {}
 
@@ -110,6 +122,8 @@ def new_product_entity(
     }
     if status:
         output["status"] = status
+    if tags:
+        output["tags"] = tags
     return output
 
 
@@ -119,6 +133,8 @@ def new_version_entity(
     task_id=None,
     thumbnail_id=None,
     author=None,
+    status=None,
+    tags=None,
     attribs=None,
     data=None,
     entity_id=None
@@ -128,10 +144,12 @@ def new_version_entity(
     Args:
         version (int): Is considered as unique identifier of version
             under product.
-        product_id (str): Id of parent product.
-        task_id (Optional[str]]): Id of task under which product was created.
-        thumbnail_id (Optional[str]]): Thumbnail related to version.
-        author (Optional[str]]): Name of version author.
+        product_id (str): Parent product id.
+        task_id (Optional[str]): Task id under which product was created.
+        thumbnail_id (Optional[str]): Thumbnail related to version.
+        author (Optional[str]): Name of version author.
+        status (Optional[str]): Version status.
+        tags (Optional[List[str]]): List of tags.
         attribs (Optional[Dict[str, Any]]): Explicitly set attributes
             of version.
         data (Optional[Dict[str, Any]]): Version entity custom data.
@@ -140,8 +158,8 @@ def new_version_entity(
 
     Returns:
         Dict[str, Any]: Skeleton of version entity.
-    """
 
+    """
     if attribs is None:
         attribs = {}
 
@@ -164,6 +182,10 @@ def new_version_entity(
         output["thumbnailId"] = thumbnail_id
     if author:
         output["author"] = author
+    if tags:
+        output["tags"] = tags
+    if status:
+        output["status"] = status
     return output
 
 
@@ -173,6 +195,8 @@ def new_hero_version_entity(
     task_id=None,
     thumbnail_id=None,
     author=None,
+    status=None,
+    tags=None,
     attribs=None,
     data=None,
     entity_id=None
@@ -182,10 +206,12 @@ def new_hero_version_entity(
     Args:
         version (int): Is considered as unique identifier of version
             under product. Should be same as standard version if there is any.
-        product_id (str): Id of parent product.
-        task_id (Optional[str]): Id of task under which product was created.
+        product_id (str): Parent product id.
+        task_id (Optional[str]): Task id under which product was created.
         thumbnail_id (Optional[str]): Thumbnail related to version.
         author (Optional[str]): Name of version author.
+        status (Optional[str]): Version status.
+        tags (Optional[List[str]]): List of tags.
         attribs (Optional[Dict[str, Any]]): Explicitly set attributes
             of version.
         data (Optional[Dict[str, Any]]): Version entity data.
@@ -194,8 +220,8 @@ def new_hero_version_entity(
 
     Returns:
         Dict[str, Any]: Skeleton of version entity.
-    """
 
+    """
     if attribs is None:
         attribs = {}
 
@@ -215,18 +241,32 @@ def new_hero_version_entity(
         output["thumbnailId"] = thumbnail_id
     if author:
         output["author"] = author
+    if tags:
+        output["tags"] = tags
+    if status:
+        output["status"] = status
     return output
 
 
 def new_representation_entity(
-    name, version_id, attribs=None, data=None, entity_id=None
+    name,
+    version_id,
+    files,
+    status=None,
+    tags=None,
+    attribs=None,
+    data=None,
+    entity_id=None
 ):
     """Create skeleton data of representation entity.
 
     Args:
         name (str): Representation name considered as unique identifier
             of representation under version.
-        version_id (str): Id of parent version.
+        version_id (str): Parent version id.
+        files (list[dict[str, str]]): List of files in representation.
+        status (Optional[str]): Representation status.
+        tags (Optional[List[str]]): List of tags.
         attribs (Optional[Dict[str, Any]]): Explicitly set attributes
             of representation.
         data (Optional[Dict[str, Any]]): Representation entity data.
@@ -235,54 +275,83 @@ def new_representation_entity(
 
     Returns:
         Dict[str, Any]: Skeleton of representation entity.
-    """
 
+    """
     if attribs is None:
         attribs = {}
 
     if data is None:
         data = {}
 
-    return {
+    output = {
         "id": _create_or_convert_to_id(entity_id),
         "versionId": _create_or_convert_to_id(version_id),
+        "files": files,
         "name": name,
         "data": data,
         "attrib": attribs
     }
+    if tags:
+        output["tags"] = tags
+    if status:
+        output["status"] = status
+    return output
 
 
-def new_workfile_info_doc(
-    filename, folder_id, task_name, files, data=None, entity_id=None
+def new_workfile_info(
+    filepath,
+    task_id,
+    status=None,
+    tags=None,
+    attribs=None,
+    description=None,
+    data=None,
+    entity_id=None
 ):
     """Create skeleton data of workfile info entity.
 
     Workfile entity is at this moment used primarily for artist notes.
 
     Args:
-        filename (str): Filename of workfile.
-        folder_id (str): Id of folder under which workfile live.
-        task_name (str): Task under which was workfile created.
-        files (List[str]): List of rootless filepaths related to workfile.
+        filepath (str): Rootless workfile filepath.
+        task_id (str): Task under which was workfile created.
+        status (Optional[str]): Workfile status.
+        tags (Optional[List[str]]): Workfile tags.
+        attribs (Options[dic[str, Any]]): Explicitly set attributes.
+        description (Optional[str]): Workfile description.
         data (Optional[Dict[str, Any]]): Additional metadata.
         entity_id (Optional[str]): Predefined id of entity. New id is created
             if not passed.
 
     Returns:
         Dict[str, Any]: Skeleton of workfile info entity.
+
     """
+    if attribs is None:
+        attribs = {}
+
+    if "extension" not in attribs:
+        attribs["extension"] = os.path.splitext(filepath)[-1]
+
+    if description:
+        attribs["description"] = description
 
     if not data:
         data = {}
 
-    return {
+    output = {
         "id": _create_or_convert_to_id(entity_id),
-        "parent": _create_or_convert_to_id(folder_id),
-        "task_name": task_name,
-        "filename": filename,
+        "taskId": task_id,
+        "path": filepath,
         "data": data,
-        "files": files
+        "attrib": attribs
     }
+    if status:
+        output["status"] = status
+
+    if tags:
+        output["tags"] = tags
+    return output
 
 
 @six.add_metaclass(ABCMeta)
@@ -296,8 +365,8 @@ class AbstractOperation(object):
         project_name (str): On which project operation will happen.
         entity_type (str): Type of entity on which change happens.
             e.g. 'folder', 'representation' etc.
-    """
 
+    """
     def __init__(self, project_name, entity_type, session):
         self._project_name = project_name
         self._entity_type = entity_type
@@ -311,7 +380,6 @@ class AbstractOperation(object):
     @property
     def id(self):
         """Identifier of operation."""
-
         return self._id
 
     @property
@@ -322,7 +390,6 @@ class AbstractOperation(object):
     @abstractmethod
     def operation_name(self):
         """Stringified type of operation."""
-
         pass
 
     def to_data(self):
@@ -330,8 +397,8 @@ class AbstractOperation(object):
 
         Returns:
             Dict[str, Any]: Description of operation.
-        """
 
+        """
         return {
             "id": self._id,
             "entity_type": self.entity_type,
@@ -348,8 +415,8 @@ class CreateOperation(AbstractOperation):
         entity_type (str): Type of entity on which change happens.
             e.g. 'folder', 'representation' etc.
         data (Dict[str, Any]): Data of entity that will be created.
-    """
 
+    """
     operation_name = "create"
 
     def __init__(self, project_name, entity_type, data, session):
@@ -420,8 +487,8 @@ class UpdateOperation(AbstractOperation):
         update_data (Dict[str, Any]): Key -> value changes that will be set in
             database. If value is set to 'REMOVED_VALUE' the key will be
             removed. Only first level of dictionary is checked (on purpose).
-    """
 
+    """
     operation_name = "update"
 
     def __init__(
@@ -491,8 +558,8 @@ class DeleteOperation(AbstractOperation):
         entity_type (str): Type of entity on which change happens.
             e.g. 'folder', 'representation' etc.
         entity_id (str): Entity id that will be removed.
-    """
 
+    """
     operation_name = "delete"
 
     def __init__(self, project_name, entity_type, entity_id, session):
@@ -540,8 +607,8 @@ class OperationsSession(object):
 
     Args:
         project_name (str): Project name to which are operations related.
-    """
 
+    """
     def __init__(self, con=None):
         if con is None:
             con = get_server_api_connection()
@@ -568,6 +635,7 @@ class OperationsSession(object):
 
         Args:
             operation (BaseOperation): Operation that should be processed.
+
         """
         if not isinstance(
             operation,
@@ -584,8 +652,8 @@ class OperationsSession(object):
 
         Args:
             operation (BaseOperation): Operation that should be processed.
-        """
 
+        """
         self.add(operation)
 
     def extend(self, operations):
@@ -594,19 +662,17 @@ class OperationsSession(object):
         Args:
             operations (List[BaseOperation]): Operations that should be
                 processed.
-        """
 
+        """
         for operation in operations:
             self.add(operation)
 
     def remove(self, operation):
         """Remove operation."""
-
         self._operations.remove(operation)
 
     def clear(self):
         """Clear all registered operations."""
-
         self._operations = []
 
     def to_data(self):
@@ -617,7 +683,6 @@ class OperationsSession(object):
 
     def commit(self):
         """Commit session operations."""
-
         operations, self._operations = self._operations, []
         if not operations:
             return
@@ -650,8 +715,8 @@ class OperationsSession(object):
 
         Returns:
             CreateOperation: Object of update operation.
-        """
 
+        """
         operation = CreateOperation(
             project_name, entity_type, data, self
         )
@@ -672,8 +737,8 @@ class OperationsSession(object):
 
         Returns:
             UpdateOperation: Object of update operation.
-        """
 
+        """
         operation = UpdateOperation(
             project_name, entity_type, entity_id, update_data, self
         )
@@ -692,8 +757,8 @@ class OperationsSession(object):
 
         Returns:
             DeleteOperation: Object of delete operation.
-        """
 
+        """
         operation = DeleteOperation(
             project_name, entity_type, entity_id, self
         )
