@@ -1,7 +1,9 @@
+import os
 import re
 import datetime
 import uuid
 import string
+import platform
 import collections
 try:
     # Python 3
@@ -14,6 +16,11 @@ except ImportError:
 import requests
 import unidecode
 
+from .constants import (
+    SERVER_TIMEOUT_ENV_KEY,
+    DEFAULT_VARIANT_ENV_KEY,
+    SITE_ID_ENV_KEY,
+)
 from .exceptions import UrlError
 
 REMOVED_VALUE = object()
@@ -22,10 +29,82 @@ SLUGIFY_SEP_WHITELIST = " ,./\\;:!|*^#@~+-_="
 
 RepresentationParents = collections.namedtuple(
     "RepresentationParents",
-    ("version", "subset", "folder", "project")
+    ("version", "product", "folder", "project")
 )
 
 
+def get_default_timeout():
+    """Default value for requests timeout.
+
+    First looks for environment variable SERVER_TIMEOUT_ENV_KEY which
+    can affect timeout value. If not available then use 10.0 s.
+
+    Returns:
+        float: Timeout value in seconds.
+
+    """
+    try:
+        return float(os.environ.get(SERVER_TIMEOUT_ENV_KEY))
+    except (ValueError, TypeError):
+        pass
+    return 10.0
+
+
+def get_default_settings_variant():
+    """Default settings variant.
+
+    Returns:
+        str: Settings variant from environment variable or 'production'.
+
+    """
+    return os.environ.get(DEFAULT_VARIANT_ENV_KEY) or "production"
+
+
+def get_default_site_id():
+    """Site id used for server connection.
+
+    Returns:
+        Union[str, None]: Site id from environment variable or None.
+
+    """
+    return os.environ.get(SITE_ID_ENV_KEY)
+
+
+class ThumbnailContent:
+    """Wrapper for thumbnail content.
+
+    Args:
+        project_name (str): Project name.
+        thumbnail_id (Union[str, None]): Thumbnail id.
+        content_type (Union[str, None]): Content type e.g. 'image/png'.
+        content (Union[bytes, None]): Thumbnail content.
+
+    """
+    def __init__(self, project_name, thumbnail_id, content, content_type):
+        self.project_name = project_name
+        self.thumbnail_id = thumbnail_id
+        self.content_type = content_type
+        self.content = content or b""
+
+    @property
+    def id(self):
+        """Wrapper for thumbnail id."""
+        return self.thumbnail_id
+
+    @property
+    def is_valid(self):
+        """Content of thumbnail is valid.
+
+        Returns:
+            bool: Content is valid and can be used.
+
+        """
+        return (
+            self.thumbnail_id is not None
+            and self.content_type is not None
+        )
+
+
 def prepare_query_string(key_values):
     """Prepare data to query string.
 
@@ -37,8 +116,8 @@ def prepare_query_string(key_values):
 
     Returns:
         str: Query string.
-    """
 
+    """
     if not key_values:
         return ""
     return "?{}".format(urlencode(key_values))
@@ -109,8 +188,8 @@ def slugify_string(
     Returns:
         Union[str, Set[str]]: Based on 'make_set' value returns slugified
             string.
-    """
 
+    """
     tmp_string = unidecode.unidecode(input_string)
     if lower:
         tmp_string = tmp_string.lower()
@@ -163,7 +242,6 @@ def prepare_attribute_changes(old_entity, new_entity, replace=False):
 
 def prepare_entity_changes(old_entity, new_entity, replace=False):
     """Prepare changes of entities."""
-
     changes = {}
     for key, new_value in new_entity.items():
         if key == "attrib":
@@ -191,30 +269,36 @@ def _try_parse_url(url):
         return None
 
 
-def _try_connect_to_server(url):
+def _try_connect_to_server(url, timeout=None):
+    if timeout is None:
+        timeout = get_default_timeout()
     try:
         # TODO add validation if the url lead to Ayon server
-        #   - thiw won't validate if the url lead to 'google.com'
-        requests.get(url)
+        #   - this won't validate if the url lead to 'google.com'
+        requests.get(url, timeout=timeout)
 
     except BaseException:
         return False
     return True
 
 
-def login_to_server(url, username, password):
+def login_to_server(url, username, password, timeout=None):
     """Use login to the server to receive token.
 
     Args:
         url (str): Server url.
         username (str): User's username.
         password (str): User's password.
+        timeout (Optional[float]): Timeout for request. Value from
+            'get_default_timeout' is used if not specified.
 
     Returns:
         Union[str, None]: User's token if login was successfull.
             Otherwise 'None'.
-    """
 
+    """
+    if timeout is None:
+        timeout = get_default_timeout()
     headers = {"Content-Type": "application/json"}
     response = requests.post(
         "{}/api/auth/login".format(url),
@@ -222,7 +306,8 @@ def login_to_server(url, username, password):
         json={
             "name": username,
             "password": password
-        }
+        },
+        timeout=timeout,
     )
     token = None
     # 200 - success
@@ -233,47 +318,67 @@ def login_to_server(url, username, password):
     return token
 
 
-def logout_from_server(url, token):
+def logout_from_server(url, token, timeout=None):
     """Logout from server and throw token away.
 
     Args:
         url (str): Url from which should be logged out.
         token (str): Token which should be used to log out.
-    """
+        timeout (Optional[float]): Timeout for request. Value from
+            'get_default_timeout' is used if not specified.
 
+    """
+    if timeout is None:
+        timeout = get_default_timeout()
     headers = {
         "Content-Type": "application/json",
         "Authorization": "Bearer {}".format(token)
     }
     requests.post(
         url + "/api/auth/logout",
-        headers=headers
+        headers=headers,
+        timeout=timeout,
     )
 
 
-def is_token_valid(url, token):
+def is_token_valid(url, token, timeout=None):
     """Check if token is valid.
 
+    Token can be a user token or service api key.
+
     Args:
         url (str): Server url.
         token (str): User's token.
+        timeout (Optional[float]): Timeout for request. Value from
+            'get_default_timeout' is used if not specified.
 
     Returns:
         bool: True if token is valid.
+
     """
+    if timeout is None:
+        timeout = get_default_timeout()
 
-    headers = {
+    base_headers = {
         "Content-Type": "application/json",
-        "Authorization": "Bearer {}".format(token)
     }
-    response = requests.get(
-        "{}/api/users/me".format(url),
-        headers=headers
-    )
-    return response.status_code == 200
+    for header_value in (
+        {"Authorization": "Bearer {}".format(token)},
+        {"X-Api-Key": token},
+    ):
+        headers = base_headers.copy()
+        headers.update(header_value)
+        response = requests.get(
+            "{}/api/users/me".format(url),
+            headers=headers,
+            timeout=timeout,
+        )
+        if response.status_code == 200:
+            return True
+    return False
 
 
-def validate_url(url):
+def validate_url(url, timeout=None):
     """Validate url if is valid and server is available.
 
     Validation checks if can be parsed as url and contains scheme.
@@ -294,14 +399,15 @@ def validate_url(url):
 
     Args:
         url (str): Server url.
+        timeout (Optional[int]): Timeout in seconds for connection to server.
 
     Returns:
         Url which was used to connect to server.
 
     Raises:
         UrlError: Error with short description and hints for user.
-    """
 
+    """
     stripperd_url = url.strip()
     if not stripperd_url:
         raise UrlError(
@@ -329,10 +435,10 @@ def validate_url(url):
     # - this will trigger UrlError if both will crash
     if not parsed_url.scheme:
         new_url = "https://" + modified_url
-        if _try_connect_to_server(new_url):
+        if _try_connect_to_server(new_url, timeout=timeout):
             return new_url
 
-    if _try_connect_to_server(modified_url):
+    if _try_connect_to_server(modified_url, timeout=timeout):
         return modified_url
 
     hints = []
@@ -358,7 +464,7 @@ class TransferProgress:
     def __init__(self):
         self._started = False
         self._transfer_done = False
-        self._transfered = 0
+        self._transferred = 0
         self._content_size = None
 
         self._failed = False
@@ -368,25 +474,66 @@ class TransferProgress:
         self._destination_url = "N/A"
 
     def get_content_size(self):
+        """Content size in bytes.
+
+        Returns:
+            Union[int, None]: Content size in bytes or None
+                if is unknown.
+
+        """
         return self._content_size
 
     def set_content_size(self, content_size):
+        """Set content size in bytes.
+
+        Args:
+            content_size (int): Content size in bytes.
+
+        Raises:
+            ValueError: If content size was already set.
+
+        """
         if self._content_size is not None:
             raise ValueError("Content size was set more then once")
         self._content_size = content_size
 
     def get_started(self):
+        """Transfer was started.
+
+        Returns:
+            bool: True if transfer started.
+
+        """
         return self._started
 
     def set_started(self):
+        """Mark that transfer started.
+
+        Raises:
+            ValueError: If transfer was already started.
+
+        """
         if self._started:
             raise ValueError("Progress already started")
         self._started = True
 
     def get_transfer_done(self):
+        """Transfer finished.
+
+        Returns:
+            bool: Transfer finished.
+
+        """
         return self._transfer_done
 
     def set_transfer_done(self):
+        """Mark progress as transfer finished.
+
+        Raises:
+            ValueError: If progress was already marked as done
+                or wasn't started yet.
+
+        """
         if self._transfer_done:
             raise ValueError("Progress was already marked as done")
         if not self._started:
@@ -394,41 +541,117 @@ class TransferProgress:
         self._transfer_done = True
 
     def get_failed(self):
+        """Transfer failed.
+
+        Returns:
+            bool: True if transfer failed.
+
+        """
         return self._failed
 
     def get_fail_reason(self):
+        """Get reason why transfer failed.
+
+        Returns:
+            Union[str, None]: Reason why transfer
+                failed or None.
+
+        """
         return self._fail_reason
 
     def set_failed(self, reason):
+        """Mark progress as failed.
+
+        Args:
+            reason (str): Reason why transfer failed.
+
+        """
         self._fail_reason = reason
         self._failed = True
 
     def get_transferred_size(self):
-        return self._transfered
+        """Already transferred size in bytes.
 
-    def set_transferred_size(self, transfered):
-        self._transfered = transfered
+        Returns:
+            int: Already transferred size in bytes.
+
+        """
+        return self._transferred
+
+    def set_transferred_size(self, transferred):
+        """Set already transferred size in bytes.
+
+        Args:
+            transferred (int): Already transferred size in bytes.
+
+        """
+        self._transferred = transferred
 
     def add_transferred_chunk(self, chunk_size):
-        self._transfered += chunk_size
+        """Add transferred chunk size in bytes.
+
+        Args:
+            chunk_size (int): Add transferred chunk size
+                in bytes.
+
+        """
+        self._transferred += chunk_size
 
     def get_source_url(self):
+        """Source url from where transfer happens.
+
+        Note:
+            Consider this as title. Must be set using
+                'set_source_url' or 'N/A' will be returned.
+
+        Returns:
+            str: Source url from where transfer happens.
+
+        """
         return self._source_url
 
     def set_source_url(self, url):
+        """Set source url from where transfer happens.
+
+        Args:
+            url (str): Source url from where transfer happens.
+
+        """
         self._source_url = url
 
     def get_destination_url(self):
+        """Destination url where transfer happens.
+
+        Note:
+            Consider this as title. Must be set using
+                'set_source_url' or 'N/A' will be returned.
+
+        Returns:
+            str: Destination url where transfer happens.
+
+        """
         return self._destination_url
 
     def set_destination_url(self, url):
+        """Set destination url where transfer happens.
+
+        Args:
+            url (str): Destination url where transfer happens.
+
+        """
         self._destination_url = url
 
     @property
     def is_running(self):
+        """Check if transfer is running.
+
+        Returns:
+            bool: True if transfer is running.
+
+        """
         if (
             not self.started
-            or self.done
+            or self.transfer_done
             or self.failed
         ):
             return False
@@ -436,9 +659,16 @@ class TransferProgress:
 
     @property
     def transfer_progress(self):
+        """Get transfer progress in percents.
+
+        Returns:
+            Union[float, None]: Transfer progress in percents or 'None'
+                if content size is unknown.
+
+        """
         if self._content_size is None:
             return None
-        return (self._transfered * 100.0) / float(self._content_size)
+        return (self._transferred * 100.0) / float(self._content_size)
 
     content_size = property(get_content_size, set_content_size)
     started = property(get_started)
@@ -447,5 +677,23 @@ class TransferProgress:
     fail_reason = property(get_fail_reason)
     source_url = property(get_source_url, set_source_url)
     destination_url = property(get_destination_url, set_destination_url)
-    content_size = property(get_content_size, set_content_size)
     transferred_size = property(get_transferred_size, set_transferred_size)
+
+
+def create_dependency_package_basename(platform_name=None):
+    """Create basename for dependency package file.
+
+    Args:
+        platform_name (Optional[str]): Name of platform for which the
+            bundle is targeted. Default value is current platform.
+
+    Returns:
+        str: Dependency package name with timestamp and platform.
+
+    """
+    if platform_name is None:
+        platform_name = platform.system().lower()
+
+    now_date = datetime.datetime.now()
+    time_stamp = now_date.strftime("%y%m%d%H%M")
+    return "ayon_{}_{}".format(time_stamp, platform_name)
